@@ -1,3 +1,4 @@
+import logging
 import os
 import pipes
 
@@ -13,8 +14,10 @@ def get_clipboard_command() -> str:
 
 
 def write_to_clipboard(message: str, clipboard_command: str) -> None:
+    logging.debug(f"Clipboard is {clipboard_command}")
     template = pipes.Template()
     # takes in input and writes no output
     template.append(clipboard_command, "-.")
     with template.open("tempfile", "w") as clipboard:  # won't actually open a file
         clipboard.write(message)
+    logging.debug(f"writing '{message}' to clipboard")
